@@ -1,6 +1,6 @@
 #include "arg.ih"
 
-Arg::Arg(char const *optstring, int argc, char **argv) throw (Errno)
+Arg::Arg(char const *optstring, int argc, char **argv)
 :
     d_argPointer(0)
 {
